yamleam/position
Source position tracking.
Position points at a single character in the source. Both fields are
1-indexed so error messages match editor conventions (line 1 is the first
line, column 1 is the first character of a line).
Source position tracking.
Position points at a single character in the source. Both fields are
1-indexed so error messages match editor conventions (line 1 is the first
line, column 1 is the first character of a line).